% function [data, fe, nb_ech] = lire_DCF(nom_DCF, flag_export);
% 
% Lecture d'un fichier au format DCF issu de la carte d'acquisition
% Data Translation DT3016
% 
% 
% Entres: 
%   nom_DCF : nom du fichier (avec son extension implicite)
%   flag_export : si 1, on exporte chaque canal en fichier wav; 0 sinon
% 
% Sorties:
%   data : signal dans l'unit spcifie dans les enttes
%   fe : freq ech utilise  l'acquisition
%   nb_ech : longueur en echantillon de chaque signaux
%
% Exemple 
%   [data, fe, nb_ech] = lire_DCF('D:\users\cri\data\essai_cs5.dcf',1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%														
%	date : 23 juin 2006
%	auteur : Christophe Savariaux								
% 	ICP - Grenoble		
%   mj : CS le 25/09/06, ajout du flag_export
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [data, fe, nb_ech] = lire_DCF(nom_DCF,flag_export)

fid = fopen(nom_DCF,'r','l');

if (fid == -1)
  error('Erreur dans l''ouverture du fichier .DCF');
end

% Entte global
file_id = fread(fid,1,'uint32');
version = fread(fid,1,'uint32');

% on definit la longueur de l'entete
long_entete = 112;
data = [];
data_tmp= [];
nb_sgx = 0 ;
name_channel = '';

while 1
    %on increment le nombre de sgx d'entre
    nb_sgx = nb_sgx + 1;
    
    % Signal Description : SIG_DESC
    magic = fread(fid,1,'uint32');
    length = fread(fid,1,'uint32');
    nb_ech = (length - long_entete)/4;
    data_type = fread(fid,1,'uint16');
    time_axis = fread(fid,1,'uint16');
    assigned_time_axis = fread(fid,1,'int');
    start_time = fread(fid,1,'double');
    time_increment = fread(fid,1,'double');
    fe = 1/time_increment;
    scale = fread(fid,1,'double');
    offset = fread(fid,1,'double');
    eng_range_min = fread(fid,1,'double');
    eng_range_max = fread(fid,1,'double');
    length_char = fread(fid,1,'uchar');
    eng_unit = fread(fid,15,'char');
    sprintf('%s',char(eng_unit(1:length_char)));
    length_description = fread(fid,1,'uchar');
    description = fread(fid,31,'char');
    channel_tmp = sprintf('%s',char(description(1:length_description)))
    name_channel = [name_channel ' ' channel_tmp];
    
    % Maintenent on lit les donnes
    data_tmp = fread(fid,nb_ech,'float32');
    if flag_export
        nom_fich = [nom_DCF(1:end-4), '_canal', num2str(nb_sgx),'.wav'];
        wavwrite(data_tmp,fe,nom_fich);
        data_tmp=[];
    else
        data = [data data_tmp];
    end
    % on teste si on est a la fin du fichier
    fscanf(fid, '%c', 1);
    if (feof(fid) == 1) % on sort
        if flag_export
            msg = [num2str(nb_sgx) ' fichiers wav gnrs !'];
        else
            msg = ['Fichier contenant ' num2str(nb_sgx) ' entres : ' name_channel];
        end
        disp(msg)
        break
    else
        % sinon on recule d'un element
        fseek(fid,-1,0);
    end
end % while 1 

fclose(fid);

