%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% norm_intens.m                                                          %
% Ponderation de l'intensit entre fichiers wav d'un mme rpertoire     %
% pour ramener l'intensit moyenne de tous les fichiers  la mme valeur %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                        %
% Mode d'emploi:                                                         %
% Se placer dans le rpertoire contenant tous les fichiers wav           %
% Lancer norm_intens.                                                    %
%                                                                        %
% Fonctionnement:                                                        %
%   1: Lecture de tous les fichiers wav, dtermination de                %
%      leur intensit moyenne puis de la moyenne de ces                  %
%      intensits moyennes                                               %
%   2: dtermination du coefficient de pondration pour chaque wav       %
%      pour se ramener  l'intensit moyenne de tous les wav             %
%   3: pondration de chaque fichier et enregistrement                   %
%      des signaux pondrs avec le suffixe _norm.                       %
%   4: Vrification que tous les fichiers ont la mme intensit moyenne  %
%      aprs traitement (le pgm affiche RMS: vecteur des intensits      %
%      moyennes de chaque fichiers puis RMS_test: mme chose mais        %
%      aprs traitement: il faut que RMS_test ne comporte que des valeurs%
%      identiques)                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Marion Dohen                                                         %
%   Nov. 2008                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

d = dir;
% calcul du nb de fichiers  traiter
nb_files = 0;
for i = 1:length(d)
    if strfind(d(i).name,'.wav')>0
        nb_files = nb_files + 1;
    end
end

%1: Lecture de tous les fichiers wav et dtermination de l'intensit
%   moyenne + calcul de la moyenne de ces intensits moyennes

RMS_moy = 0; % moyenne des intensits moyennes
RMS = zeros(nb_files,1); % vecteur des intensits moyennes
sig_max = zeros(nb_files,1); % vecteur des valeurs max de chaque wav
index = 0;
for i = 1:length(d)
    if strfind(d(i).name,'.wav')>0
        index = index + 1;
        nof = d(i).name;
        [sig,fs] = wavread(nof);
        temp = 0;
        sig_max(index)=max(abs(sig));
        for j = 1:length(sig)
            temp = temp + sig(j)^2;
        end
        RMS(index) = sqrt(temp/length(sig));
        RMS_moy = RMS_moy + RMS(index);
    end
end
if length(RMS)~=nb_files
    display('ATTENTION: PB DE COMPATIBILITE ENTRE LA TAILLE DE RMS ET LE NB DE FICHIERS');
end
RMS_moy = RMS_moy/nb_files;
RMS_moy = 0.2
%   2: dtermination du coefficient de pondration pour chaque wav       %
%      pour se ramener  l'intensit moyenne de tous les wav             %
coeff = zeros(nb_files,1);
index = 0;
coeff_anti_clip = 1;
for i = 1:length(d)
    if strfind(d(i).name,'.wav')>0
         index = index + 1;
         coeff(index)=(RMS_moy/RMS(index));
         if (sig_max(index)*coeff(index)>1) && (sig_max(index)*coeff(index)>coeff_anti_clip)
             coeff_anti_clip = sig_max(index)*coeff(index);
         end
    end
end
index = 0;
for i = 1:length(d)
    if strfind(d(i).name,'.wav')>0
         index = index + 1;
         coeff(index)=(RMS_moy/RMS(index))/coeff_anti_clip;
    end
end

%   3: pondration de chaque fichier et enregistrement                   %
%      des signaux pondrs avec le suffixe _norm.                       %
index = 0;
for i = 1:length(d)
    if strfind(d(i).name,'.wav')>0
        index = index+1;
        nof = d(i).name
        [sig,fs] = wavread(nof);
        sig_norm = sig*coeff(index);
        test_max = max(abs(sig_norm));
        if test_max>1
            display('PROBLEME: VALEURS SUP A 1: RISQUE DE CLIPING');
        end
        prefix = nof(1:strfind(nof,'.wav')-1);
        nof_norm = [prefix '_norm.wav'];
        wavwrite(sig_norm,fs,nof_norm);
    end
end 

%   4: Vrification que tous les fichiers ont la mme intensit moyenne
%      aprs traitement
RMS_test = zeros(nb_files,1); % vecteur des intensits moyennes
index = 0;
d = dir;
for i = 1:length(d)
    if strfind(d(i).name,'_norm.wav')>0
        index = index + 1;
        nof = d(i).name;
        [sig,fs] = wavread(nof);
        temp = 0;
        for j = 1:length(sig)
            temp = temp + sig(j)^2;
        end
        RMS_test(index) = sqrt(temp/length(sig));
    end
end
RMS
RMS_moy
RMS_test
