function tac2asc(nom_fich_tac,param)

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function tac2asc : met au format ASCII en colonne les valeurs des
%  parametres contenu dans param pour lecture sous PRAAT ou TRAP
%  Sauvegrade dans un fichier .lev
%
%  Remarque : les parametres de sortie sont toujours stocks dans l'ordre 
%             A B S P1 P2 C
%  
%  Exemple d'utilisation :
%   tac2asc('d:\temp\ruhi2.tac',['A' 'P1' 'S']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%														
%	date : 13/09/02
%	auteur : Christophe Savariaux								
% 	ICP - Grenoble		
%	Modifs : 													
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% On ouvre le fichier .tac
[Val, TC, NbLignes, Nb_err, TC_err] = charge_tacle(nom_fich_tac);

% Cration et ouverture du fichier de sortie
nomfich_out = [nom_fich_tac(1:length(nom_fich_tac)-4), '.lev'];

fid_f = fopen(nomfich_out,'wt');
if (fid_f == -1)
    errordlg('Erreur d''ouverture du fichier report !!','Erreur','on');
    return;
end

sortie = [];
ind = 0;
fprintf(fid_f, '%s', '#');

% On cherche ce qui est demand
if ~isempty(findstr('A',param))
    ind = ind+1;
    sortie(ind,:) = Val(1,:);
    fprintf(fid_f, '%s\t', 'A');
end
if ~isempty(findstr('B',param))
   ind = ind+1;    
   sortie(ind,:) = Val(2,:);
   fprintf(fid_f, '%s\t', 'B');
end
if ~isempty(findstr('S',param)) 
    ind = ind+1;   
    sortie(ind,:) = Val(3,:);
   fprintf(fid_f, '%s\t', 'S');
end
if ~isempty(findstr('P1',param)) 
    ind = ind+1;   
    sortie(ind,:) = Val(4,:);
   fprintf(fid_f, '%s\t', 'P1');
end
if ~isempty(findstr('P2',param)) 
    ind = ind+1;   
    sortie(ind,:) = Val(5,:);
   fprintf(fid_f, '%s\t', 'P2');
end
if ~isempty(findstr('C',param)) 
    ind = ind+1;
    sortie(ind,:) = Val(6,:);
   fprintf(fid_f, '%s\t', 'C');
end


fprintf(fid_f, '\n');

%On sauve les resultats
if ind == 1
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\n', sortie(1,i));
    end
elseif ind == 2
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i));
    end
elseif ind == 3
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i));
    end
elseif ind == 4
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i), sortie(4,i));
    end
elseif ind == 5
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i), sortie(4,i), sortie(5,i));
    end
elseif ind == 6
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n',sortie(1,i),sortie(2,i),sortie(3,i),sortie(4,i),sortie(5,i),sortie(6,i));
    end
end

msg = ['Fichier de paramtres cr dans : ' nomfich_out];
msgbox(msg,'Info');

fclose(fid_f);
